@@ -14,6 +14,7 @@ func main() {
 	cmdVersion := cmd.MakeVersion()
 	cmdJoin := cmd.MakeJoin()
 	cmdUpdate := cmd.MakeUpdate()
+	cmdReady := cmd.MakeReady()
 
 	printk3supASCIIArt := cmd.PrintK3supASCIIArt
 
@@ -52,6 +53,7 @@ func main() {
 	rootCmd.AddCommand(cmdVersion)
 	rootCmd.AddCommand(cmdJoin)
 	rootCmd.AddCommand(cmdUpdate)
+	rootCmd.AddCommand(cmdReady)
 
 	if err := rootCmd.Execute(); err != nil {
 		os.Exit(1)
